#ifndef QMEDIAINFO_H
#define QMEDIAINFO_H

#include <QFileInfoList>
#include <QMainWindow>
#include <QNetworkReply>
#include <QSettings>
#include <QTextCodec>

#include "ui_qmediainfo.h"

class QMediaInfo : public QMainWindow, private Ui::MainWindow
{
  Q_OBJECT

public:
  QMediaInfo(QWidget *parent = 0);

private:
  QActionGroup *group;
  QFileInfoList filesList;
  QSettings *settings;
  QString supportedFiles;

private slots:
  bool MIInstalled();
  QStringList launchMI(QString filePath);
  void addToComboBox(const QStringList itemList);
  void checkUpdates();
  void exportInfo(QString file, QString type);
  void fillHiddenItems(const QStringList itemList);
  void fillPseudoTree(const QStringList infoList);
  void fillTextBrowser(const QStringList infoList);
  void fillTree(const QStringList infoList);
  void loadFiles(QStringList files);
  void loadSettings();
  void loadTranslation();
  void on_actionAboutMediaInfo_triggered();
  void on_actionAboutQt_triggered();
  void on_actionAbout_triggered();
  void on_actionCloseAll_triggered();
  void on_actionCloseCurrent_triggered();
  void on_actionExit_triggered();
  void on_actionSupportedFiles_triggered();
  void on_actionToHTML_triggered();
  void on_actionToPlain_triggered();
  void on_actionToXML_triggered();
  void on_btnAdd_clicked();
  void on_chBoxSplitES_stateChanged(int value);
  void on_checkBoxFullInfo_stateChanged(int value);
  void on_checkBoxWordWrap_stateChanged(int value);
  void on_cmbBoxFiles_currentIndexChanged(int index);
  void on_groupBoxHiddenItems_clicked(bool checked);
  void on_groupBoxHiddenItems_toggled(bool value);
  void on_openFilesAction_triggered();
  void on_openFolderAction_triggered();
  void on_spinBoxSplit_valueChanged(int value);
  void replyFinished(QNetworkReply* reply);
  void updateInfo();

protected:
  void closeEvent(QCloseEvent *);
  virtual void dragEnterEvent(QDragEnterEvent *);
  virtual void dropEvent(QDropEvent *);
};

#endif // QMEDIAINFO_H

